@@ -6,6 +6,7 @@ and more.
 """
 
 import logging
+from enum import StrEnum
 from typing import Literal, Self
 from urllib.parse import urlparse
 
@@ -14,6 +15,14 @@ from pydantic import BaseModel, Field, PostgresDsn, SecretStr, model_validator
 from archipy.models.errors import FailedPreconditionError, InvalidArgumentError
 
 
+class RedisMode(StrEnum):
+    """Redis deployment mode."""
+
+    STANDALONE = "standalone"
+    SENTINEL = "sentinel"
+    CLUSTER = "cluster"
+
+
 class ElasticsearchConfig(BaseModel):
     """Configuration settings for Elasticsearch connections and operations.
 
@@ -549,18 +558,60 @@ class PrometheusConfig(BaseModel):
 class RedisConfig(BaseModel):
     """Configuration settings for Redis cache integration.
 
-    Controls Redis server connection parameters and client behavior settings.
+    Supports standalone, sentinel, and cluster deployments.
     """
 
-    MASTER_HOST: str | None = Field(default=None, description="Redis master host")
-    SLAVE_HOST: str | None = Field(default=None, description="Redis slave host")
-    PORT: int = Field(default=6379, description="Redis server port")
-    DATABASE: int = Field(default=0, description="Redis database number")
+    # Deployment mode
+    MODE: RedisMode = Field(default=RedisMode.STANDALONE, description="Redis deployment mode")
+
+    # Standalone mode settings (existing)
+    MASTER_HOST: str | None = Field(default="localhost", description="Redis master host (standalone/sentinel)")
+    SLAVE_HOST: str | None = Field(default=None, description="Redis slave host (standalone)")
+
+    # Cluster mode settings
+    CLUSTER_NODES: list[str] = Field(default=[], description="List of cluster node addresses (host:port)")
+    CLUSTER_REQUIRE_FULL_COVERAGE: bool = Field(default=True, description="Require full cluster coverage")
+    CLUSTER_READ_FROM_REPLICAS: bool = Field(default=True, description="Allow reading from replica nodes")
+    CLUSTER_SKIP_FULL_COVERAGE_CHECK: bool = Field(default=False, description="Skip full coverage check for testing")
+
+    # Sentinel mode settings
+    SENTINEL_NODES: list[str] = Field(default=[], description="List of sentinel addresses (host:port)")
+    SENTINEL_SERVICE_NAME: str | None = Field(default=None, description="Master service name for sentinel")
+    SENTINEL_SOCKET_TIMEOUT: float = Field(default=0.1, description="Sentinel socket timeout")
+
+    # Common settings
+    PORT: int = Field(default=6379, description="Default Redis server port")
+    DATABASE: int = Field(default=0, description="Redis database number (not used in cluster)")
     PASSWORD: str | None = Field(default=None, description="Redis password")
     DECODE_RESPONSES: Literal[True] = Field(default=True, description="Whether to decode responses")
     VERSION: int = Field(default=7, description="Redis protocol version")
     HEALTH_CHECK_INTERVAL: int = Field(default=10, description="Health check interval in seconds")
 
+    # Connection pooling
+    MAX_CONNECTIONS: int = Field(default=50, description="Maximum connections per node")
+    RETRY_ON_TIMEOUT: bool = Field(default=True, description="Retry operations on timeout")
+    SOCKET_CONNECT_TIMEOUT: float = Field(default=5.0, description="Socket connection timeout")
+    SOCKET_TIMEOUT: float = Field(default=5.0, description="Socket operation timeout")
+
+    @model_validator(mode="after")
+    def validate_mode_configuration(self) -> Self:
+        """Validate mode-specific configuration."""
+        if self.MODE == RedisMode.CLUSTER:
+            if not self.CLUSTER_NODES:
+                raise ValueError("CLUSTER_NODES must be provided when MODE is 'cluster'")
+            if self.DATABASE != 0:
+                logging.warning("DATABASE setting ignored in cluster mode")
+
+        elif self.MODE == RedisMode.SENTINEL:
+            if not self.SENTINEL_NODES or not self.SENTINEL_SERVICE_NAME:
+                raise ValueError("SENTINEL_NODES and SENTINEL_SERVICE_NAME required for sentinel mode")
+
+        elif self.MODE == RedisMode.STANDALONE:
+            if not self.MASTER_HOST:
+                raise ValueError("MASTER_HOST required for standalone mode")
+
+        return self
+
 
 class SentryConfig(BaseModel):
     """Configuration settings for Sentry error tracking integration.
@@ -725,3 +776,106 @@ class ParsianShaparakConfig(BaseModel):
         default=None,
         description="Optional HTTP/HTTPS proxy configuration dictionary",
     )
+
+
+class TemporalConfig(BaseModel):
+    """Configuration settings for Temporal workflow engine integration.
+
+    Controls connection parameters, security settings, and timeout configurations
+    for Temporal workflow orchestration services.
+
+    Attributes:
+        HOST (str): Temporal server host address.
+        PORT (int): Temporal server port number.
+        NAMESPACE (str): Temporal namespace for workflow isolation.
+        TASK_QUEUE (str): Default task queue for workflow and activity execution.
+        TLS_CA_CERT (str | None): Path to TLS CA certificate for secure connections.
+        TLS_CLIENT_CERT (str | None): Path to TLS client certificate for mutual authentication.
+        TLS_CLIENT_KEY (str | None): Path to TLS client private key.
+        WORKFLOW_EXECUTION_TIMEOUT (int): Maximum workflow execution time in seconds.
+        WORKFLOW_RUN_TIMEOUT (int): Maximum single workflow run time in seconds.
+        WORKFLOW_TASK_TIMEOUT (int): Maximum workflow task processing time in seconds.
+        ACTIVITY_START_TO_CLOSE_TIMEOUT (int): Maximum activity execution time in seconds.
+        ACTIVITY_HEARTBEAT_TIMEOUT (int): Activity heartbeat timeout in seconds.
+        RETRY_MAXIMUM_ATTEMPTS (int): Maximum retry attempts for failed activities.
+        RETRY_BACKOFF_COEFFICIENT (float): Backoff multiplier for retry delays.
+        RETRY_MAXIMUM_INTERVAL (int): Maximum retry interval in seconds.
+    """
+
+    HOST: str = Field(default="localhost", description="Temporal server host address")
+    PORT: int = Field(default=7233, ge=1, le=65535, description="Temporal server port number")
+    NAMESPACE: str = Field(default="default", description="Temporal namespace for workflow isolation")
+    TASK_QUEUE: str = Field(default="task-queue", description="Default task queue name")
+
+    # TLS Configuration
+    TLS_CA_CERT: str | None = Field(default=None, description="Path to TLS CA certificate")
+    TLS_CLIENT_CERT: str | None = Field(default=None, description="Path to TLS client certificate")
+    TLS_CLIENT_KEY: str | None = Field(default=None, description="Path to TLS client private key")
+
+    # Workflow Timeout Settings
+    WORKFLOW_EXECUTION_TIMEOUT: int = Field(
+        default=300,
+        ge=1,
+        description="Maximum workflow execution time in seconds",
+    )
+    WORKFLOW_RUN_TIMEOUT: int = Field(
+        default=60,
+        ge=1,
+        description="Maximum single workflow run time in seconds",
+    )
+    WORKFLOW_TASK_TIMEOUT: int = Field(
+        default=30,
+        ge=1,
+        description="Maximum workflow task processing time in seconds",
+    )
+
+    # Activity Timeout Settings
+    ACTIVITY_START_TO_CLOSE_TIMEOUT: int = Field(
+        default=30,
+        ge=1,
+        description="Maximum activity execution time in seconds",
+    )
+    ACTIVITY_HEARTBEAT_TIMEOUT: int = Field(
+        default=10,
+        ge=1,
+        description="Activity heartbeat timeout in seconds",
+    )
+
+    # Retry Configuration
+    RETRY_MAXIMUM_ATTEMPTS: int = Field(
+        default=3,
+        ge=1,
+        description="Maximum retry attempts for failed activities",
+    )
+    RETRY_BACKOFF_COEFFICIENT: float = Field(
+        default=2.0,
+        ge=1.0,
+        description="Backoff multiplier for retry delays",
+    )
+    RETRY_MAXIMUM_INTERVAL: int = Field(
+        default=60,
+        ge=1,
+        description="Maximum retry interval in seconds",
+    )
+
+    @model_validator(mode="after")
+    def validate_tls_configuration(self) -> Self:
+        """Validate TLS configuration consistency."""
+        tls_fields = [self.TLS_CA_CERT, self.TLS_CLIENT_CERT, self.TLS_CLIENT_KEY]
+        tls_provided = [field for field in tls_fields if field is not None]
+
+        if len(tls_provided) > 0 and len(tls_provided) != 3:
+            raise InvalidArgumentError()
+
+        return self
+
+    @model_validator(mode="after")
+    def validate_timeout_hierarchy(self) -> Self:
+        """Validate timeout configuration hierarchy."""
+        if self.WORKFLOW_RUN_TIMEOUT >= self.WORKFLOW_EXECUTION_TIMEOUT:
+            raise InvalidArgumentError()
+
+        if self.WORKFLOW_TASK_TIMEOUT >= self.WORKFLOW_RUN_TIMEOUT:
+            raise InvalidArgumentError()
+
+        return self
